
# This file was automatically generated by Dist::Zilla::Plugin::ModuleBuild v6.010.
use strict;
use warnings;

use Module::Build 0.28;


my %module_build_args = (
  "build_requires" => {
    "Module::Build" => "0.28"
  },
  "configure_requires" => {
    "Module::Build" => "0.28"
  },
  "dist_abstract" => "my perl module and CLIs for Biology",
  "dist_author" => [
    "Yan Xueqing <yanxueqing621\@163.com>"
  ],
  "dist_name" => "Bioinfo",
  "dist_version" => "0.1.7",
  "license" => "perl",
  "module_name" => "Bioinfo",
  "recursive_test_files" => 1,
  "requires" => {
    "Exporter" => 0,
    "FindBin" => 0,
    "IO::All" => 0,
    "List::Util" => 0,
    "Modern::Perl" => 0,
    "Moo" => 0,
    "MooX::Cmd" => 0,
    "MooX::Options" => 0,
    "Moose" => 0,
    "Parallel::ForkManager" => 0,
    "XML::Twig" => 0,
    "lib" => 0,
    "namespace::autoclean" => 0,
    "namespace::clean" => 0,
    "strict" => 0,
    "warnings" => 0
  },
  "script_files" => [
    "bin/biotools"
  ],
  "test_requires" => {
    "Test::More" => "0.88",
    "Test::Pod" => 0,
    "Test::Pod::Coverage" => "1.00"
  }
);


my %fallback_build_requires = (
  "Module::Build" => "0.28",
  "Test::More" => "0.88",
  "Test::Pod" => 0,
  "Test::Pod::Coverage" => "1.00"
);


unless ( eval { Module::Build->VERSION(0.4004) } ) {
  delete $module_build_args{test_requires};
  $module_build_args{build_requires} = \%fallback_build_requires;
}

my $build = Module::Build->new(%module_build_args);


$build->create_build_script;
