package Bioinfo;
use Moo;
use Modern::Perl;
use namespace::clean;

our $VERSION = '0.1.7'; # VERSION: 
# ABSTRACT: my perl module and CLIs for Biology


1;

__END__

=pod

=encoding UTF-8

=head1 NAME

Bioinfo - my perl module and CLIs for Biology

=head1 VERSION

version 0.1.7

=head1 SYNOPSIS

  use Bioinfo;
  ...

=head1 DESCRIPTION

=head1 AUTHOR

Yan Xueqing <yanxueqing621@163.com>

=head1 COPYRIGHT AND LICENSE

This software is copyright (c) 2017 by Yan Xueqing.

This is free software; you can redistribute it and/or modify it under
the same terms as the Perl 5 programming language system itself.

=cut
